@@ -70,12 +70,12 @@ knh_Exception_struct_init(Ctx *ctx, knh_Exception_struct *b, int init, Object *c
 /* ------------------------------------------------------------------------ */
 
 void
-knh_Exception_struct_traverse(Ctx *ctx, knh_Exception_struct *b, f_traverse gc)
+knh_Exception_struct_traverse(Ctx *ctx, knh_Exception_struct *b, knh_ftraverse gc)
 {
 	gc(ctx, UP(b->message));
 	gc(ctx, b->bag);
 	gc(ctx, UP(b->traces));
-	//if(isSWEEP(gc)) KNH_FREE(something);
+	//if(isSWEEP(gc)) KNH_FREE(ctx, something);
 }
 
 /* ======================================================================== */
@@ -89,7 +89,7 @@ Exception* knh_Exception_new__init(Ctx *ctx, Exception *o, String *e, String *ms
 {
 	knh_expt_t eid = EXPT_Exception;
 	if(IS_NOTNULL(e)) {
-		eid = knh_texpt_forname(ctx, knh_String_tobytes(e), EXPT_unknown);
+		eid = knh_texpt_forname(ctx, knh_String_tobytes(e), EXPT_newid /*EXPT_unknown*/);
 	}
 	if(eid == EXPT_unknown) {
 		KNH_WARNING(ctx, "unknown exception: %s", knh_String_tochar(e));
@@ -170,19 +170,43 @@ Exception* new_Exception__Nue(Ctx *ctx, knh_Nue_t *nue)
 
 /* ------------------------------------------------------------------------ */
 
-KNHAPI(Exception*) new_Exception__errno(Ctx *ctx)
+#define _KNH_PERRNO(ctx, emsg, func) { \
+		knh_perrno(ctx, emsg, func, __FILE__, __LINE__); \
+	}\
+
+/* ------------------------------------------------------------------------ */
+
+KNHAPI(void) knh_perrno(Ctx *ctx, char *emsg, char *func, char *file, int line)
 {
-#ifdef KNH_USING_POSIX
-	char buf[40];
-	knh_snprintf(buf, sizeof(buf), "Errno!!: errno=%d", errno);
-	return new_Exception__b(ctx, B(buf));
-#else
-	return new_Exception__s(ctx, "Error!!: errno=UNKNOWN");
-#endif
+	if(emsg == NULL) emsg = "Exception!!";
+	if(errno == 13) {
+		emsg = "Security!!";
+	}
+	if(((ctx)->flag & KNH_FLAG_CTXF_STRICT) != KNH_FLAG_CTXF_STRICT) {
+		char buf[256];
+		knh_snprintf(buf, sizeof(buf), "%s: func=%s, errno=%d: %s", emsg, func, errno, strerror(errno));
+		knh_throwException(ctx, new_Exception__b(ctx, B(buf)), KNH_SAFEFILE(file), line);
+	}
+	else {
+		KNH_NOTICE(ctx, "%s() says errno=%d: %s", func, errno, strerror(errno));
+	}
 }
 
 /* ------------------------------------------------------------------------ */
 
+KNHAPI(void) knh_throw_OutOfIndex(Ctx *ctx, knh_integer_t n, size_t max, char *file, int line)
+{
+	char buf[80];
+	knh_snprintf(buf, sizeof(buf), "OutOfIndex!!: %d <%d", (int)n, (int)max);
+	knh_throwException(ctx, new_Exception__b(ctx, B(buf)), KNH_SAFEFILE(file), line);
+}
+
+#define _KNH_THROW_OUTOFINDEX(ctx, n, max) { \
+		knh_throw_OutOfIndex(ctx, n, max, __FILE__, __LINE__); \
+	}\
+
+/* ------------------------------------------------------------------------ */
+
 
 #ifdef __cplusplus
 }
