@@ -69,7 +69,7 @@ void knh_NameSpace_struct_init(Ctx *ctx, knh_NameSpace_struct *b, int init, Obje
 
 /* ------------------------------------------------------------------------ */
 
-void knh_NameSpace_struct_traverse(Ctx *ctx, knh_NameSpace_struct *b, f_traverse ftr)
+void knh_NameSpace_struct_traverse(Ctx *ctx, knh_NameSpace_struct *b, knh_ftraverse ftr)
 {
 	ftr(ctx, UP(b->parent));
 	ftr(ctx, UP(b->nsname));
@@ -129,9 +129,18 @@ void knh_NameSpace_setClass(Ctx *ctx, NameSpace *o, String *name, knh_class_t c)
 knh_class_t knh_NameSpace_getClass(Ctx *ctx, NameSpace *o, knh_bytes_t name)
 {
 	if(knh_bytes_equals(name, STEXT("Script")) && IS_NOTNULL(DP(o)->script)) {
-		//DBG_P("Script cid = %s", CLASSN(knh_Object_cid(DP(o)->script)));
 		return knh_Object_cid(DP(o)->script);
 	}
+	if(knh_bytes_equals(name, STEXT("This"))) {
+		return CLASS_This;
+	}
+
+	knh_index_t loc = knh_bytes_index(name, '<');
+	if(loc > 0) {
+		TODO(); // This strips C<T> to C */
+		name = knh_bytes_first(name, loc);
+	}
+
 	NameSpace *ns = o;
 	L_TAIL:;
 	knh_uint_t cid = knh_DictSet_get__b(DP(ns)->name2cidDictSet, name);
@@ -293,36 +302,47 @@ knh_NameSpace_getFuncClass(Ctx *ctx, NameSpace *o, knh_bytes_t funcname)
 /* [const] */
 
 knh_bool_t
-knh_NameSpace_existsLocalConst(Ctx *ctx, NameSpace *o, knh_bytes_t name)
+knh_NameSpace_existsConst(Ctx *ctx, NameSpace *o, knh_bytes_t name)
 {
-	if(IS_NOTNULL(DP(o)->lconstDictMap)) {
-		return (knh_DictMap_index__b(DP(o)->lconstDictMap, name) != -1);
+	if(knh_bytes_index(name, '_') == -1) {
+		if(IS_NOTNULL(DP(o)->lconstDictMap)) {
+			return (knh_DictMap_index__b(DP(o)->lconstDictMap, name) != -1);
+		}
+		return 0;
 	}
-	return 0;
+	return knh_tConst_exists(ctx, name);
 }
 
 /* ------------------------------------------------------------------------ */
 
-void knh_NameSpace_addLocalConst(Ctx *ctx, NameSpace *o, String *name, Object *value)
+void knh_NameSpace_addConst(Ctx *ctx, NameSpace *o, String *name, Object *value)
 {
 	KNH_ASSERT(IS_NameSpace(o));
 	KNH_ASSERT(IS_String(name));
-	if(IS_NULL(DP(o)->lconstDictMap)) {
-		KNH_SETv(ctx, DP(o)->lconstDictMap, new_DictMap0(ctx, 16));
+	if(knh_bytes_index(knh_String_tobytes(name), '_') == -1) {
+		if(IS_NULL(DP(o)->lconstDictMap)) {
+			KNH_SETv(ctx, DP(o)->lconstDictMap, new_DictMap0(ctx, 16));
+		}
+		knh_DictMap_set(ctx, DP(o)->lconstDictMap, name, value);
+	}
+	else {
+		knh_tConst_addGlobalConst(ctx, name, value);
 	}
-	knh_DictMap_set(ctx, DP(o)->lconstDictMap, name, value);
 }
 
 
 /* ------------------------------------------------------------------------ */
 
 Object*
-knh_NameSpace_getLocalConst(Ctx *ctx, NameSpace *o, knh_bytes_t name)
+knh_NameSpace_getConst(Ctx *ctx, NameSpace *o, knh_bytes_t name)
 {
-	if(IS_NOTNULL(DP(o)->lconstDictMap)) {
-		return knh_DictMap_get__b( DP(o)->lconstDictMap, name);
+	if(knh_bytes_index(name, '_') == -1) {
+		if(IS_NOTNULL(DP(o)->lconstDictMap)) {
+			return knh_DictMap_get__b( DP(o)->lconstDictMap, name);
+		}
+		return (Object*)KNH_NULL;
 	}
-	return (Object*)KNH_NULL;
+	return knh_tConst_value(ctx, name);
 }
 
 /* ======================================================================== */
