@@ -66,7 +66,7 @@ knh_OutputStream_struct_init(Ctx *ctx, knh_OutputStream_struct *b, int init, Obj
 /* ------------------------------------------------------------------------ */
 
 void
-knh_OutputStream_struct_traverse(Ctx *ctx, knh_OutputStream_struct *b, f_traverse gc)
+knh_OutputStream_struct_traverse(Ctx *ctx, knh_OutputStream_struct *b, knh_ftraverse gc)
 {
 	if(IS_SWEEP(gc) && b->fd != -1) {
 		b->driver.fclose(ctx, b->fd);
@@ -95,10 +95,10 @@ Object *knh_OutputStream_open(Ctx *ctx, OutputStream *o, String *urn, String *mo
 		DP(o)->driver = *(knh_System_getIODriver(ctx, knh_bytes_first(fname, loc)));
 	}
 	if(IS_NULL(mode)) {
-		DP(o)->fd = DP(o)->driver.fopen(ctx, UP(o), fname, "w");
+		DP(o)->fd = DP(o)->driver.fopen(ctx, NULL, o, fname, "w");
 	}
 	else {
-		DP(o)->fd = DP(o)->driver.fopen(ctx, UP(o), fname, knh_String_tochar(mode));
+		DP(o)->fd = DP(o)->driver.fopen(ctx, NULL, o, fname, knh_String_tochar(mode));
 	}
 
 	if(DP(o)->fd != -1) {
@@ -170,6 +170,7 @@ void knh_OutputStream_clear(Ctx *ctx, OutputStream *o)
 
 void knh_OutputStream_close(Ctx *ctx, OutputStream *o)
 {
+	knh_OutputStream_flush(ctx, o);
 	f_io_close f = DP(o)->driver.fclose;
 	DP(o)->driver = knh_System_getDefaultIODriver();
 	f(ctx, DP(o)->fd);
@@ -264,7 +265,7 @@ KNHAPI(OutputStream*) new_FileOutputStream(Ctx *ctx, knh_bytes_t file, char *mod
 	knh_OutputStream_setBOL(o, 1);
 
 	DP(o)->driver = *(knh_System_getIODriver(ctx, STEXT("file")));
-	DP(o)->fd = DP(o)->driver.fopen(ctx, UP(o), file, mode);
+	DP(o)->fd = DP(o)->driver.fopen(ctx, NULL, o, file, mode);
 	if(DP(o)->fd != -1) {
 		KNH_SETv(ctx, DP(o)->ba, new_Bytes(ctx, DP(o)->driver.bufsiz));
 		KNH_SETv(ctx, DP(o)->urn, new_String(ctx, file, NULL));
