@@ -320,7 +320,7 @@ void knh_StmtMETHOD_name(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, int
 		rztype = mtd_cid;
 	}
 
-	if(IS_NULL(mtd)) {
+	if(IS_NULL(mtd) || knh_methodn_isNew(mn)) {
 		int i, psize = DP(cpr)->vars_size;
 		//DEBUG3("PSIZE=%d", psize);
 		MethodField *mf = knh_tMethodField_find(ctx, cpr, rztype, psize);
@@ -349,6 +349,7 @@ void knh_StmtMETHOD_name(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, int
 		//DEBUG3("PSIZE=%d", psize);
 
 		MethodField *mf = DP(mtd)->mf;
+		//DEBUG3("(mtd)->cid=%s, mtd_cid=%s", CLASSN(DP(mtd)->cid), CLASSN(mtd_cid));
 		if(DP(mtd)->cid != mtd_cid) {
 			if(knh_Method_isFinal(mtd)) {
 				char bufcm[CLASSNAME_BUFSIZ];
@@ -361,6 +362,7 @@ void knh_StmtMETHOD_name(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, int
 			KNH_SETv(ctx, DP(mtd)->mf, mf);
 			knh_Class_addMethod(ctx, mtd_cid, mtd);
 		}
+
 		if(!knh_StmtMETA_isOverride(stmt) && !knh_Method_isAbstract(mtd) && DP(mtd)->mn != METHODN_main) {
 			char bufcm[CLASSNAME_BUFSIZ];
 			knh_format_cmethodn(bufcm, sizeof(bufcm), mtd_cid, mn);
@@ -368,6 +370,7 @@ void knh_StmtMETHOD_name(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, int
 			knh_Stmt_done(ctx, stmt);
 			return;
 		}
+
 		if(DP(mf)->params[0].type != rztype) {
 			knh_wbuf_t wb = knh_Context_wbuf(ctx);
 			knh_Method__k(ctx, mtd, wb.w, (String*)KNH_NULL);
@@ -376,6 +379,7 @@ void knh_StmtMETHOD_name(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, int
 			knh_Stmt_done(ctx, stmt);
 			return;
 		}
+
 		if(psize != DP(mf)->size) {
 			knh_wbuf_t wb = knh_Context_wbuf(ctx);
 			knh_Method__k(ctx, mtd, wb.w, (String*)KNH_NULL);
