@@ -38,7 +38,11 @@
 #define KONOHA_VERSION   PACKAGE_VERSION
 #else
 #define KONOHA_NAME     "konoha"
-#define KONOHA_VERSION  "0.2.2"
+#define KONOHA_VERSION  "0.2.3"
+#endif
+
+#ifndef KNH_DBGMODE2
+#define KNH_FASTMODE    1
 #endif
 
 #define KONOHA_URL		"http://konoha.sourceforge.jp/"
@@ -140,8 +144,6 @@
 
 /* ======================================================================== */
 
-//#define KNH_FASTMODE 1
-
 #ifdef KNH_FASTMODE
 #define KNH_USING_FASTMALLOC 1
 #define KNH_USING_WORDKLRC   1
