@@ -62,8 +62,6 @@ extern "C" {
 #define KNH_MT_VOLATILE
 #endif
 
-#define KNH_USING_INT64 1
-
 /* ------------------------------------------------------------------------ */
 
 /* ------------------------------------------------------------------------ */
@@ -84,7 +82,6 @@ typedef signed long int           knh_int_t;    /* sizeof(knh_int_t) = sizeof(*p
 #define KNH_INT_FMTX              "%lx"
 #define KNH_INT_BSIZE             (sizeof(knh_int_t))
 #define KNH_INT_FMTSIZ            40
-#define knh_abs(n)                labs(n)
 
 typedef unsigned long int         knh_uint_t;   /* sizeof(knh_uint_t) = sizeof(*p) */
 #define KNH_UINT_MAX              ULONG_MAX
@@ -229,22 +226,7 @@ typedef unsigned long long int         knh_uint64_t;
 /* Integer, knh_integer_t */
 /* ------------------------------------------------------------------------ */
 
-#ifdef KNH_USING_INT64
-
-#define knh_integer_t    knh_int64_t
-#define knh_uinteger_t   knh_uint64_t
-
-#define KNH_INTEGER_MAX               LLONG_MAX
-#define KNH_INTEGER_MIN               LLONG_MIN
-#define KNH_INTEGER_FMT               "%lld"
-#define KNH_INTEGER_XFMT              "%llx"
-#define KNH_INTEGER_BSIZE             (sizeof(knh_integer_t))
-#define KNH_INTEGER_FMTSIZ            40
-#define KNH_UINTEGER_MAX              ULLONG_MAX
-#define KNH_UINTEGER_MIN              0
-#define KNH_UINTEGER_FMT              "%llu"
-
-#else /*KNH_USING_INT64*/
+#ifdef KNH_USING_INT32
 
 #define knh_integer_t    knh_int_t
 #define knh_uinteger_t   knh_uint_t
@@ -258,8 +240,25 @@ typedef unsigned long long int         knh_uint64_t;
 #define KNH_UINTEGER_MAX              ULONG_MAX
 #define KNH_UINTEGER_MIN              0
 #define KNH_UINTEGER_FMT              "%lu"
+#define knh_abs(n)                labs(n)
 
-#endif/*KNH_USING_INT64*/
+#else /*KNH_USING_INT32*/
+
+#define knh_integer_t    knh_int64_t
+#define knh_uinteger_t   knh_uint64_t
+
+#define KNH_INTEGER_MAX               LLONG_MAX
+#define KNH_INTEGER_MIN               LLONG_MIN
+#define KNH_INTEGER_FMT               "%lld"
+#define KNH_INTEGER_XFMT              "%llx"
+#define KNH_INTEGER_BSIZE             (sizeof(knh_integer_t))
+#define KNH_INTEGER_FMTSIZ            40
+#define KNH_UINTEGER_MAX              ULLONG_MAX
+#define KNH_UINTEGER_MIN              0
+#define KNH_UINTEGER_FMT              "%llu"
+#define knh_abs(n)                llabs(n)
+
+#endif/*KNH_USING_INT32*/
 
 #define _DCAST(t,v)     ((t)v)
 
@@ -329,7 +328,7 @@ typedef struct knh_Object_t {
 } knh_Object_t ;
 
 #ifdef KNH_OBJECT_MAGIC
-	#ifdef KONOHA_FASTMODE
+	#ifdef KNH_FASTMODE
 		#define KNH_ASSERT_ISOBJECT(o)
 	#else
 		#define KNH_ASSERT_ISOBJECT(o)        KNH_ASSERT((o)->h.magic == KNH_OBJECT_MAGIC)
@@ -354,6 +353,7 @@ typedef struct knh_Object_t {
 /* Context */
 /* ------------------------------------------------------------------------ */
 
+#define ARG_size(a)        ((size_t)(a.i)->value)
 #define ARG_int(a)         ((knh_int_t)(a.i)->value)
 #define ARG_uint(a)        ((knh_uint_t)(a.i)->value)
 #define ARG_integer(a)     ((a.i)->value)
@@ -487,21 +487,22 @@ typedef knh_uint_t                knh_stackop_t;
 /* ------------------------------------------------------------------------ */
 
 typedef unsigned char           knhvmc_t;          /* knh_vmc_t */
-#ifdef KNH_FASTMODE
-typedef unsigned int            knhvm_opcode_t;
-typedef signed int              knhvm_i1_t;
-typedef unsigned int            knhvm_u1_t;
-typedef signed int              knhvm_i2_t;
-typedef unsigned int            knhvm_u2_t;
-typedef signed int              knhvm_ebp_t;
-typedef signed int              knhvm_sfp_t;
-typedef signed int              knhvm_ofp_t;
-typedef signed int              knhvm_addr_t;
-typedef unsigned int            knhvm_class_t;
-typedef unsigned int            knhvm_methodn_t;
-typedef unsigned int            knhvm_expt_t;
-typedef unsigned int            knhvm_line_t;
-#else
+
+#ifdef KNH_USING_WORDKLRC    /*KNH_FASTMODE*/
+typedef knh_uint_t            knhvm_opcode_t;
+typedef knh_int_t             knhvm_i1_t;
+typedef knh_uint_t            knhvm_u1_t;
+typedef knh_int_t             knhvm_i2_t;
+typedef knh_uint_t            knhvm_u2_t;
+typedef knh_int_t             knhvm_ebp_t;
+typedef knh_int_t             knhvm_sfp_t;
+typedef knh_int_t             knhvm_ofp_t;
+typedef knh_int_t             knhvm_addr_t;
+typedef knh_uint_t            knhvm_class_t;
+typedef knh_uint_t            knhvm_methodn_t;
+typedef knh_uint_t            knhvm_expt_t;
+typedef knh_uint_t            knhvm_line_t;
+#else/*KNH_USING_WORDKLRC*/
 typedef unsigned char           knhvm_opcode_t;
 typedef char                    knhvm_i1_t;
 typedef unsigned char           knhvm_u1_t;
@@ -515,7 +516,7 @@ typedef knh_class_t             knhvm_class_t;
 typedef knh_methodn_t           knhvm_methodn_t;
 typedef knh_expt_t              knhvm_expt_t;
 typedef knh_int_t               knhvm_line_t;
-#endif
+#endif/*KNH_USING_WORDKLRC*/
 
 /* ------------------------------------------------------------------------ */
 
@@ -580,9 +581,9 @@ typedef struct {
 
 typedef knh_int_t knh_io_t;
 
-typedef knh_io_t (*f_io_open)(Ctx *ctx, Object *io, knh_bytes_t urn, char *mode);
-typedef size_t (*f_io_read)(Ctx *ctx, knh_io_t fd, char *buf, size_t bufsiz);
-typedef size_t (*f_io_write)(Ctx *ctx, knh_io_t fd, char *buf, size_t bufsiz);
+typedef knh_io_t (*f_io_open)(Ctx *ctx, struct knh_InputStream_t *in, struct knh_OutputStream_t *out, knh_bytes_t urn, char *mode);
+typedef knh_int_t (*f_io_read)(Ctx *ctx, knh_io_t fd, char *buf, size_t bufsiz);
+typedef knh_int_t (*f_io_write)(Ctx *ctx, knh_io_t fd, char *buf, size_t bufsiz);
 typedef void   (*f_io_close)(Ctx *ctx, knh_io_t fd);
 
 typedef struct {
@@ -639,12 +640,12 @@ typedef struct {
 /* KNH_DRVAPI_TYPE__DB */
 
 typedef void   knh_db_t;
-typedef        knh_db_t* (*knh_fdbopen)(Ctx *ctx, knh_bytes_t url);
-typedef struct knh_ResultSet_t* (*knh_fdbquery)(Ctx *ctx, knh_db_t *, knh_bytes_t query);
+typedef void   knh_dbcur_t;
+struct knh_ResultSet_t;
+typedef knh_db_t* (*knh_fdbopen)(Ctx *ctx, knh_bytes_t url);
+typedef knh_dbcur_t* (*knh_fdbquery)(Ctx *ctx, knh_db_t *, knh_bytes_t query, struct knh_ResultSet_t*);
 typedef void   (*knh_fdbclose)(Ctx *ctx, knh_db_t *);
 
-struct knh_ResultSet_t;
-typedef void   knh_dbcur_t;
 typedef int    (*knh_fdbcurnext)(Ctx *, knh_dbcur_t *, struct knh_ResultSet_t*);
 typedef void   (*knh_fdbcurfree)(knh_dbcur_t *);
 
