@@ -541,11 +541,6 @@ int knh_Method_pctoline(Method *mtd, knhvmc_t *pc);
 		knh_throwException(ctx, new_Exception(ctx, TS_SecurityException), KNH_SAFEFILE(__FILE__), __LINE__); \
 	} \
 
-#define KNH_BESTRICT(ctx, ff, cc) { \
-		if((ff cc) && ((ctx)->flag & KNH_FLAG_CTXF_STRICT) != KNH_FLAG_CTXF_STRICT) { \
-			knh_throwException(ctx, new_Exception__errno(ctx), KNH_SAFEFILE(__FILE__), __LINE__); \
-		} \
-	}\
 
 /* ------------------------------------------------------------------------ */
 
