@@ -38,6 +38,39 @@ extern "C" {
 /* ======================================================================== */
 /* [konoha] */
 
+static int optionAdmin = 0;
+static int optionCompiling = 0;
+
+/* ----------------------------------------------------------------------- */
+
+KNHAPI(int) konoha_setopt(int argc, char **argv)
+{
+	int n;
+	for(n = 1; n < argc; n++) {
+		char *t = argv[n];
+		if(t[0] != '-') return n;
+		if(t[1] == 's' && t[2] == 0) {
+			optionAdmin = 1; continue;
+		}
+		if(t[1] == 'c' && t[2] == 0) {
+			optionCompiling = 1; continue;
+		}
+	}
+	return n;
+}
+
+/* ------------------------------------------------------------------------ */
+
+KNHAPI(void) konoha_context_initOption(Ctx *ctx)
+{
+	if(optionAdmin == 1) {
+		knh_Context_setAdmin(ctx, 1);
+	}
+	if(optionCompiling == 1) {
+		knh_Context_setCompiling(ctx, 1);
+	}
+}
+
 /* ------------------------------------------------------------------------ */
 
 static int knh_systemIsInitialized = 0;
@@ -56,6 +89,7 @@ void konoha_init0()
 	knh_tClass_init0();
 	knh_tExpt_init0();
 	konoha_class_init0(NULL);
+	knh_srand(0);
 }
 
 /* ------------------------------------------------------------------------ */
